#
# spec file for package rnnoise
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname librnnoise0
Name:           rnnoise
Version:        0.2
Release:        2.1
Summary:        Recurrent neural network for audio noise reduction
License:        BSD-3-Clause
URL:            https://gitlab.xiph.org/xiph/rnnoise
Source:         https://gitlab.xiph.org/xiph/rnnoise/-/archive/v%{version}/rnnoise-v%{version}.tar.gz
Source1:        https://media.xiph.org/rnnoise/models/rnnoise_data-0b50c45.tar.gz
# PATCH-FIX-UPSTREAM - https://github.com/xiph/rnnoise/issues/222
Patch1:         372f7b4.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
Requires:       python3-Keras

%description
RNNoise is a noise suppression library based on a recurrent neural network.
This package holds the training tools.

%package -n %{libname}
Summary:        Recurrent neural network for audio noise reduction - Shared library

%description -n %{libname}
RNNoise is a noise suppression library based on a recurrent neural network.

This package holds the shared library.

%package devel
Summary:        Recurrent neural network for audio noise reduction - Development Files
Requires:       %{libname} = %{version}

%description devel
RNNoise is a noise suppression library based on a recurrent neural network.

This package holds the development files.

%prep
%autosetup -p1 -n %{name}-v%{version}

%build
cp -p %{SOURCE1} .
./autogen.sh
%configure \
 --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
rm -rf %{buildroot}%{_datadir}/doc/%{name}/{AUTHORS,COPYING,README}

%post   -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%doc README TRAINING-README
%license COPYING
%{_libdir}/librnnoise.so.0*

%files devel
%{_includedir}/rnnoise.h
%{_libdir}/librnnoise.so
%{_libdir}/pkgconfig/rnnoise.pc

%changelog
* Mon Apr 22 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add upstream patch to fix build:
  * 372f7b4.patch
* Mon Apr 15 2024 Dirk Müller <dmueller@suse.com>
- update to 0.2:
  * many improvements, including improved training, SSE4.1 and AVX2
    optimizations, and run-time CPU detection (RTCD).
  * The distributed models are now trained using only publicly
    available datasets
* Sat Dec 16 2023 dead_mozay@opensuse.org
- Update to version 0.git20210312.7f449bf:
  * Add link to paper and demo to the README
  * Correct #endif in rnn.h.
  * Document the API
  * Add rnnoise_get_frame_size()
  * Drop unused arguments from README (#103)
  * fix inclusion of rnnoise.h into C++ code
  * Document in the README the authorative source for the code.
  * docs: fix simple typo, delares -> declares
  * rename TRAINING -> TRAINING-README for case insensitive file system
  * Update celt_lpc.c
* Wed Jul  7 2021 dead_mozay@opensuse.org
- Update to version 0.git20210122.1cbdbcf:
  * Drop unused arguments from README (#103)
  * docs: fix simple typo, delares -> declares
  * rename TRAINING -> TRAINING-README for case insensitive file system
  * Access files in binary mode
* Fri Sep  4 2020 Marcus Rueckert <mrueckert@suse.de>
- initial package
